export declare enum TransferValidationStatus {
    Pending = "pending",
    Valid = "valid",
    Invalid = "invalid",
    Error = "error"
}
export interface EnergyTransferRequestPublicAttrs {
    id: number;
    generatorId: string;
    sellerAddress: string;
    buyerAddress: string;
    volume: string;
    transferDate: Date;
}
export interface EnergyTransferRequestAttrs extends EnergyTransferRequestPublicAttrs {
    createdAt: Date;
    updatedAt: Date;
    certificateId: number | null;
    isCertificatePersisted: boolean;
    validationStatusRecord: Record<string, TransferValidationStatus>;
    computedValidationStatus: TransferValidationStatus;
}
interface NewAttributesParams {
    buyerAddress: string;
    sellerAddress: string;
    volume: string;
    generatorId: string;
    transferDate: Date;
}
export declare class EnergyTransferRequest {
    private attrs;
    private constructor();
    get certificateId(): number | null;
    get id(): number;
    get sites(): {
        buyerAddress: string;
        sellerAddress: string;
    };
    get volume(): string;
    isValid(): boolean;
    updateCertificateId(certificateId: number): void;
    markCertificatePersisted(): void;
    startValidation(validatorNames: string[]): void;
    updateValidationStatus(validatorName: string, status: TransferValidationStatus): void;
    toAttrs(): EnergyTransferRequestAttrs;
    toPublicAttrs(): EnergyTransferRequestPublicAttrs;
    static fromAttrs(attrs: EnergyTransferRequestAttrs): EnergyTransferRequest;
    static newAttributes(params: NewAttributesParams): Omit<EnergyTransferRequestAttrs, 'id'>;
}
export {};
